=========================
Using reclass with Puppet
=========================

.. todo::

  The adapter between |reclass| and `Puppet`_ has not actually been written,
  since I rage-quit using Puppet before the rewrite of |reclass|.

  It should be trivial to do, and if you need it or are interested in working
  on it, and you require assistance, please get in touch with me `on the
  mailing list <mailto:reclass@pantsfullofunix.net>`_. Else just send the
  patch!

.. include:: extrefs.inc
.. include:: substs.inc
